## Code for FSIS' 2023 Risk Assessments


#######################################
##### SET WORKING DIRECTORY       #####
#######################################

# Notes on files/etc

# Use 'setwd' to identify working directory where all files are saved
# e.g., setwd('Documents/FSIS_2023_Salm_Risk_Assessment_Model_Code/Turkey/Final_Product')


#######################################
##### LOAD LIBRARIES              #####
#######################################

library(glue)
library(dplyr)
library(tidyr)
library(truncnorm)
library(mc2d)
library(ggplot2)

#######################################
##### SOURCE SUPPORTING FUNCTIONS #####
#######################################

#Begin EpiX

#SET WORKING DIRECTORY (setwd) TO ACCESS POLYNOMIAL2.CSV FILE
source("EpiX_To_Source_Aug_2023.R")  #EpiX Analytics dose-response code. Please see notes in code

#End EpiX

################################################################################
################################################################################
################################################################################

# Begin FSIS 


# FUNCTIONS CREATED SPECIFICALLY FOR COMMINUTED TURKEY MODELS

final_prod_std = function(conc.thresh, p.c1, mu.init, sig.init, iter, atten.mu.X = -5, DR.est="Mean") {
  
  #########################################################################################
  # Human cases of salmonellosis partitioned to comminuted turkey                         #
  #########################################################################################
  
  FoodNet.cases <- 7600     # per year
  share.food <-	0.66        # foodborne fraction (else is waterborne)
  share.foreign <- 0.11     # foreign travel associated illnesses 
  FoodNet.coverage <- 0.15  # FoodNet sites comprise 15% of U.S. population
  UnderDx.mult <-	24.3      # number of true cases for each reported case
  
  # total salmonellosis illnesses annually
  Tot.salm.yr	<- FoodNet.cases * share.food * (1-share.foreign) * UnderDx.mult/FoodNet.coverage
  round(Tot.salm.yr)
  
  turk.attrib <- 0.059      # share of all illnesses attributed to turkey consumption
  
  # total illnesses from turkey products annually
  turk.ill <- turk.attrib * Tot.salm.yr
  round(turk.ill)
  
  ground.share <- 0.42      # share of turkey illnesses from comminuted consumption
  
  # total illnesses from comminuted turkey annually
  num.ill <- turk.ill * ground.share 
  round(num.ill)
  
  # total lots (i.e., days of production for comminuted turkey)
  tot.lots <- 8120 
  
  # actual total samples collected per year
  tot.sam.act <- 1355
  
  # #lognormal (log10) concentration parameters (represents between lot variability) 
  # #default params for comminuted turkey provided in function arguments
  # mu.init
  # sig.init
  
  # attenuation distribution 
  log.atten.mu <- atten.mu.X
  log.atten.sig <- 1.91
  
  
  #########################################################################################
  # Begin model here                                                                      #
  #########################################################################################
  
  # fraction of tested-failed lots that will be diverted among all noncompliant lots 
  alpha.compfrac <- tot.sam.act/tot.lots
  # alpha.compfrac  
  
  # calc exposure (dose) distribution as combination of init concentration and attenuation
  log.dose.mu <- mu.init + log.atten.mu
  log.dose.sig <- sqrt(sig.init^2+log.atten.sig^2)
  
  # calculate prob of illness for each cluster across all exposures
  p.ill.dose.C1 <- integrate(f,-Inf, Inf, mu=log.dose.mu, sigma=log.dose.sig, cluster=1, est=DR.est)$value 
  p.ill.dose.C2 <- integrate(f,-Inf, Inf, mu=log.dose.mu, sigma=log.dose.sig, cluster=2, est=DR.est)$value
  
  # calculate a baseline probability of illness across all exposures
  # need to weight by frequency of seroclusters 
  p.ill.dose <- p.c1 * p.ill.dose.C1 + (1-p.c1) * p.ill.dose.C2
  # p.ill.dose.C1/p.ill.dose.C2
  
  
  
  
  
  # Prepare for simulation depending on concentration thresholds provided for FPS
  num.conc <- length(conc.thresh)

  # initiate output
  out <- NULL
  
  # loop through simulation scenarios
  for (k in 1:num.conc) {
    
    # probability a lot fails threshold
    p.lot.fail <- 1-pnorm(log10(conc.thresh[k]),mu.init,sig.init)
    # p.lot.fail 
    
    # this is omega in our basic equation (fraction of lots that pass)
    omega <- 1-p.lot.fail
    # omega
    
    # number of tested lots that will fail
    lots.fail <- tot.sam.act * p.lot.fail
    # round(lots.fail) 
    
    # number of all lots that are non-compliant
    lots.noncompliant <- tot.lots * p.lot.fail
    # round(lots.noncompliant)
    
    #  Need probability of illness given passing and failing.
    #  Because Dose-response functions depend on serocluster,
    #  need to weight each p(ill | passing/failing) by serocluster 1 and 2 results.
    
    # simulate p.ill for passing lots 
    pass.init <- 10^rtruncnorm(iter,a=-Inf,b=log10(conc.thresh[k]),mu.init,sig.init)
    atten <- 10^rnorm(iter,log.atten.mu,log.atten.sig)
    dose.pass <- pass.init*atten
    Response.dose.pass <- DRPoly(dose.pass)
    p.ill.dose.pass.C1 <- as.numeric(colMeans(Response.dose.pass)[1])
    p.ill.dose.pass.C2 <- as.numeric(colMeans(Response.dose.pass)[4])
    
    # calculate p.ill for failing lots
    p.ill.dose.fail.C1 <- (p.ill.dose.C1 - omega*p.ill.dose.pass.C1)/(1-omega)
    p.ill.dose.fail.C2 <- (p.ill.dose.C2 - omega*p.ill.dose.pass.C2)/(1-omega)
    
    # combine results for passing and failing lots
    p.ill.dose.pass <- p.c1 * p.ill.dose.pass.C1 + 
      (1-p.c1) * p.ill.dose.pass.C2
    p.ill.dose.fail <- p.c1 * p.ill.dose.fail.C1 + 
      (1-p.c1) * p.ill.dose.fail.C2
    
    fail.pass <- p.ill.dose.fail/p.ill.dose.pass  #this ratio changes with conc.thresh
    
    # compare these with EpiX intended ratio of ~2.1/0.38=5.5 (dose-response based on mix of exposure distributions)
    passC1.C2 <- p.ill.dose.pass.C1/p.ill.dose.pass.C2
    failC1.C2 <- p.ill.dose.fail.C1/p.ill.dose.fail.C2
    
    p.ill.base <- omega*p.ill.dose.pass + (1-omega)*p.ill.dose.fail
    
    # calculate the new probability of illness per serving after diverting noncompliant lots
    p.ill.new <- omega*p.ill.dose.pass + (1-omega)*
      ((alpha.compfrac)*p.ill.base+(1-alpha.compfrac)*p.ill.dose.fail)
    
    # calculate newer probability of illness per serving if replace with passing lots
    p.ill.newer <- (omega+alpha.compfrac-omega*alpha.compfrac)*p.ill.dose.pass + 
      (1-omega)*(1-alpha.compfrac)*p.ill.dose.fail
    
    # calculate illnesses avoided per year
    ill.avoid <- (1-(p.ill.new/p.ill.base))*num.ill
    
    ill.avoid.lot <- ill.avoid/lots.fail
    
    ill.avoid.newer <- round((1-(p.ill.newer/p.ill.base))*num.ill)
    
    perc.red <- (1-(p.ill.new/p.ill.base))
    perc.red.newer <- (1-(p.ill.newer/p.ill.base))
    
    print(glue("Completed concentration threshold {conc.thresh[k]} ({k} of {length(conc.thresh)} scenario sims)"))
    
    # current FPS results
    tmp.out <- data.frame(
      mu.init,
      sig.init,
      log.atten.mu,
      conc.thresh=conc.thresh[k],p.c1,iter,
      fail.pass,
      passC1.C2,
      failC1.C2,
      p.ill.base,
      p.ill.new,
      p.ill.newer,
      ill.avoid,
      ill.avoid.newer,
      ill.avoid.lot,
      perc.red,
      perc.red.newer,
      p.ill.dose.pass.C1,
      p.ill.dose.pass.C2,
      p.ill.dose.fail.C1,
      p.ill.dose.fail.C2
    )
    
    # append current FPS results to full output
    out <- rbind(out,tmp.out)
  }
  
  # return results
  return(out)
  
}

reduce_c1_scenario = function(p.c1.current) {
  
  #########################################################################################
  # Human cases of salmonellosis partitioned to comminuted turkey                         #
  #########################################################################################
  
  FoodNet.cases <- 7600     # per year
  share.food <-	0.66        # foodborne fraction (else is waterborne)
  share.foreign <- 0.11     # foreign travel associated illnesses 
  FoodNet.coverage <- 0.15  # FoodNet sites comprise 15% of U.S. population
  UnderDx.mult <-	24.3      # number of true cases for each reported case
  
  # total salmonellosis illnesses annually
  Tot.salm.yr	<- FoodNet.cases * share.food * (1-share.foreign) * UnderDx.mult/FoodNet.coverage
  # round(Tot.salm.yr)
  
  turk.attrib <- 0.059      # share of all illnesses attributed to turkey consumption
  
  # total illnesses from turkey products annually
  turk.ill <- turk.attrib * Tot.salm.yr
  # round(turk.ill)
  
  ground.share <- 0.42      # share of turkey illnesses from comminuted consumption
  
  # total illnesses from comminuted turkey annually
  num.ill <- turk.ill * ground.share 
  # round(num.ill)
  
  # lognormal (log10) concentration parameters (represents between lot variability) 
  mu.init <- -4.857 
  sig.init <- 2.333
  
  # attenuation distribution 
  log.atten.mu <- -5
  log.atten.sig <- 1.91
  
  # calc exposure (dose) distribution as combination of init concentration and attenuation
  log.dose.mu <- mu.init + log.atten.mu
  log.dose.sig <- sqrt(sig.init^2+log.atten.sig^2)
  
  # calculate prob of illness for each cluster across all exposures
  p.ill.dose.C1 <- integrate(f,-Inf, Inf, mu=log.dose.mu, sigma=log.dose.sig, cluster=1, est="Mean")$value 
  p.ill.dose.C2 <- integrate(f,-Inf, Inf, mu=log.dose.mu, sigma=log.dose.sig, cluster=2, est="Mean")$value
  
  # calculate a baseline probability of illness across all exposures
  # need to weight by frequency of seroclusters 
  p.ill.dose <- p.c1.current * p.ill.dose.C1 + (1-p.c1.current) * p.ill.dose.C2

  # just reduce p.C1 from current status
  p.c1.new <- seq(0,p.c1.current,0.01)
  
  p.ill.dose.new <- p.c1.new * p.ill.dose.C1 + (1-p.c1.new) * p.ill.dose.C2
  
  ill.avoided.pc1 <- (1-(p.ill.dose.new/p.ill.dose))*num.ill
  
  red.pc1 <- (p.c1.current-p.c1.new)/p.c1.current
  
  return(data.frame(red.pc1,ill.avoided.pc1))
}

final_prod_approx_method = function(conc.thresh, p.c1) {
  
  #########################################################################################
  # Human cases of salmonellosis partitioned to comminuted turkey                         #
  #########################################################################################
  
  FoodNet.cases <- 7600     # per year
  share.food <-	0.66        # foodborne fraction (else is waterborne)
  share.foreign <- 0.11     # foreign travel associated illnesses 
  FoodNet.coverage <- 0.15  # FoodNet sites comprise 15% of U.S. population
  UnderDx.mult <-	24.3      # number of true cases for each reported case
  
  # total salmonellosis illnesses annually
  Tot.salm.yr	<- FoodNet.cases * share.food * (1-share.foreign) * UnderDx.mult/FoodNet.coverage
  round(Tot.salm.yr)
  
  turk.attrib <- 0.059      # share of all illnesses attributed to turkey consumption
  
  # total illnesses from turkey products annually
  turk.ill <- turk.attrib * Tot.salm.yr
  round(turk.ill)
  
  ground.share <- 0.42      # share of turkey illnesses from comminuted consumption
  
  # total illnesses from comminuted turkey annually
  num.ill <- turk.ill * ground.share 
  round(num.ill)
  
  # total lots (i.e., days of production for comminuted turkey)
  tot.lots <- 8120 
  
  # actual total samples collected per year
  tot.sam.act <- 1355
  
  # lognormal (log10) concentration parameters (represents between lot variability) 
  mu.init <- -4.857 
  sig.init <- 2.333
  
  # attenuation distribution 
  log.atten.mu <- -5
  log.atten.sig <- 1.91
  
  
  #########################################################################################
  # Begin model here                                                                      #
  #########################################################################################
  
  # fraction of tested-failed lots that will be diverted among all noncompliant lots 
  alpha.compfrac <- tot.sam.act/tot.lots
  # alpha.compfrac  
  
  # calc exposure (dose) distribution as combination of init concentration and attenuation
  log.dose.mu <- mu.init + log.atten.mu
  log.dose.sig <- sqrt(sig.init^2+log.atten.sig^2)
  
  # calculate prob of illness for each cluster across all exposures
  p.ill.dose.C1 <- integrate(f,-Inf, Inf, mu=log.dose.mu, sigma=log.dose.sig, cluster=1, est="Mean")$value 
  p.ill.dose.C2 <- integrate(f,-Inf, Inf, mu=log.dose.mu, sigma=log.dose.sig, cluster=2, est="Mean")$value
  
  # calculate a baseline probability of illness across all exposures
  # need to weight by frequency of seroclusters 
  p.ill.dose <- p.c1 * p.ill.dose.C1 + (1-p.c1) * p.ill.dose.C2
  # p.ill.dose.C1/p.ill.dose.C2
  
  # probability a lot fails threshold
  p.lot.fail <- 1-pnorm(log10(conc.thresh),mu.init,sig.init)
  # p.lot.fail 
  
  # this is omega in our basic equation (fraction of lots that pass)
  omega <- 1-p.lot.fail
  # omega
  
  # mean integer value of initial contaminantion distribution
  init_Mean <- exp(mu.init*log(10)+0.5*(sig.init*log(10))^2)
  # init_Mean

  # calculate conditional exp values of lognormal directly
  cndlE_pass <- (exp(mu.init*log(10)+0.5*(sig.init*log(10))^2)*
                   pnorm((log(conc.thresh)-mu.init*log(10)-(sig.init*log(10))^2)/(sig.init*log(10))))/omega
  cndlE_pass

  cndlE_fail <- (exp(mu.init*log(10)+0.5*(sig.init*log(10))^2)-cndlE_pass*omega)/(1-omega)
  cndlE_fail

  # # illustrate weighted ev's equal mean of lognormal
  # omega*cndlE_pass+(1-omega)*cndlE_fail
  # init_Mean

  # calculate mean initial concentration after policy effect
  newMean <- omega*cndlE_pass + (1-omega)*(alpha.compfrac*init_Mean+
                                             (1-alpha.compfrac)*cndlE_fail)
  # newMean

  # calculate effect of policy to compare with full Monte Carlo estimate
  # Note: this calc completely ignores attenuation effects!
  effect.init <- 1-(newMean/init_Mean)
  # effect.init
  
  
  out <- data.frame(
    conc.thresh=conc.thresh,p.c1,
    omega,
    init_Mean,
    cndlE_pass,
    cndlE_fail,
    newMean,
    effect.init
  )
}



###########################################################################################

commturk_thresholds <- c(1/2600,1/1300,1/650,1/325,1/150,1/65,1/30,1/15,1/10,1/9,1/8,1/7,1/6,1/5,1/4,1/3,1/2,1,2,3,5,7.5,10,20,50,100)
commturk_pc1 <- 0.3
commturk_numIter <- 1000000
commturk_mu <- -4.857
commturk_sig <- 2.333

comm_turk_fps <- final_prod_std(conc.thresh=commturk_thresholds, p.c1=commturk_pc1, mu.init=commturk_mu, sig.init=commturk_sig, iter=commturk_numIter)


fname <- "my_scenario_output"

# write output to file
write.csv(comm_turk_fps, file=glue("{fname}_{Sys.Date()}.csv"), row.names=FALSE)


# generate plot
ill_avoid_scenario <- comm_turk_fps %>% pivot_longer(cols=c(ill.avoid.newer,ill.avoid),names_to="Scenario",values_to="n.avoid") %>%
  mutate(Scenario = ifelse(Scenario=="ill.avoid","replace with passing conc.","replace with baseline conc."))

ggplot(ill_avoid_scenario, aes(x=log10(conc.thresh),y=n.avoid,shape=Scenario,col=Scenario))+
  geom_point(size=2.5,alpha=0.7)+scale_color_manual(values=c("purple","darkgreen"))+
  labs(x="log10 concentration threshold scenario",y="number of illnesses avoided")+
  ylim(c(0,round(max(comm_turk_fps$ill.avoid.newer))))+
  theme_bw()+theme(text=element_text(size=12),legend.position=c(0.25,0.15))




###########################################################################
#  Demonstrate effect of reducing frequency of C1 in lots intended for comminuted turkey final product
#
#  IMPORTANT!
#  NOTE! THIS IS A HYPOTHETICAL MODEL SCENARIO; 
#  more data is REQUIRED to determine C1 vs C2 distribution in turkey lots and how that might change by final product!
#
##########################################################################

red.pc1.scenario <- reduce_c1_scenario(p.c1.current = commturk_pc1)

ggplot(red.pc1.scenario,aes(red.pc1,ill.avoided.pc1))+
  geom_point()+
  labs(y="number of illnesses avoided",x="Reduction in fraction of C1")+
  theme_bw()+theme(text=element_text(size=12))




#########################################################################################
#  Demonstrate the approximation approach in comparison with full simulation
#
# THE APPROPRIATE ARRAY OF conc.thresh. MUST BE EVALUATED FOR BOTH APPROACHES 
#
#########################################################################################

turk.effect <- final_prod_approx_method(conc.thresh = commturk_thresholds, p.c1 = commturk_pc1)

# THE FOLLOWING ARRAYS WERE GENERATED FROM SIMULATING THE FULL MODEL'S perc.red VARIABLE AT THE SAME CONC THRESHOLDS!!!!
turk_sim <- comm_turk_fps$perc.red

my_df <- data.frame(conc.thresh=turk.effect$conc.thresh,
                    comm.effect=turk.effect$effect.init,
                    comm.sim=turk_sim) %>%
  pivot_longer(cols = !conc.thresh, names_to = "approach", values_to="perc.red") %>%
  mutate(approach = ifelse(approach=="comm.effect","Approximation","Full simulation"))

ggplot(my_df, aes(log10(conc.thresh),perc.red,col=approach,shape=approach))+
  geom_point(size=2.5,alpha=0.75)+
  labs(x="log10 concentration threshold scenario", y="proportional reduction in illnesses",col="Model approach",shape="Model approach")+
  theme_bw()+theme(text=element_text(size=12),legend.position=c(0.25,0.15))




###############################################################################################
# THE FOLLOWING EXPLAINS CHANGES IN MODEL INPUTS TO CONDUCT THE SENSITIVITY ANALYSIS DESCRIBED
# IN THE REPORT.  
###############################################################################################

# To examine the effect of changes to the attenuation distribution on the proportional reduction in 
# illnesses for a range of concentration thresholds, the model was simulated after modifying
# log.atten.mu <- X, where X was entered as -9 or +2.  
# The output perc.red is saved for graphing purposes.

sens.atten.1 <- final_prod_std(conc.thresh=commturk_thresholds, p.c1=commturk_pc1, mu.init=commturk_mu, sig.init=commturk_sig, iter=commturk_numIter, atten.mu.X = -9)
sens.atten.2 <- final_prod_std(conc.thresh=commturk_thresholds, p.c1=commturk_pc1, mu.init=commturk_mu, sig.init=commturk_sig, iter=commturk_numIter, atten.mu.X = 2)


# To examine the effect of changes to the initial contamination distribution on the proportional reduction
# in illnesses for a range of concentration thresholds, the model was simulated after modifying separately
# the inputs mu.init=-4.857 and sig.init=2.333 by adding or subtracting 1 to each value. 
# The output perc.red is saved for graphing purposes.

sens.mu.1 <- final_prod_std(conc.thresh=commturk_thresholds, p.c1=commturk_pc1, mu.init=commturk_mu+1, sig.init=commturk_sig, iter=commturk_numIter)
sens.mu.2 <- final_prod_std(conc.thresh=commturk_thresholds, p.c1=commturk_pc1, mu.init=commturk_mu-1, sig.init=commturk_sig, iter=commturk_numIter)

sens.sig.1 <- final_prod_std(conc.thresh=commturk_thresholds, p.c1=commturk_pc1, mu.init=commturk_mu, sig.init=commturk_sig+1, iter=commturk_numIter)
sens.sig.2 <- final_prod_std(conc.thresh=commturk_thresholds, p.c1=commturk_pc1, mu.init=commturk_mu, sig.init=commturk_sig-1, iter=commturk_numIter)


# To examine the effect of changing the probability of Cluster 1 organisms on the proportional reduction
# in illnesses for a range of concentration thresholds, the model was simulated after modifying the input
# p.c1 <- 0.3 to either 0 or 1. The output perc.red is saved for graphing purposes.  

sens.pc1.0 <- final_prod_std(conc.thresh=commturk_thresholds, p.c1=0, mu.init=commturk_mu, sig.init=commturk_sig, iter=commturk_numIter)
sens.pc1.1 <- final_prod_std(conc.thresh=commturk_thresholds, p.c1=1, mu.init=commturk_mu, sig.init=commturk_sig, iter=commturk_numIter)


# To examine the effect of changes to the C1 and C2 dose-response functions on the proportional reduction
# in illnesses for a range of concentration thresholds, the model was simulated after the following 
# modifications; 
# p.ill.dose.C1 <- integrate(f,-Inf, Inf, mu=log.dose.mu, sigma=log.dose.sig, cluster=1, est="X")$value 
# p.ill.dose.C2 <- integrate(f,-Inf, Inf, mu=log.dose.mu, sigma=log.dose.sig, cluster=2, est="X")$value
# where X=High or Low, and 
# p.ill.dose.pass.C1 <- as.numeric(colMeans(Response.dose.pass)[X])
# p.ill.dose.pass.C2 <- as.numeric(colMeans(Response.dose.pass)[Y])
# where X=3 and Y=6 for the upper bound dose-response functions and X=2 and Y=5 for the lower bound
# dose response functions. The output perc.red is saved for graphing purposes.

sens.dr.low <- final_prod_std(conc.thresh=commturk_thresholds, p.c1=commturk_pc1, mu.init=commturk_mu, sig.init=commturk_sig, iter=commturk_numIter, DR.est="Low")
sens.dr.high <- final_prod_std(conc.thresh=commturk_thresholds, p.c1=commturk_pc1, mu.init=commturk_mu, sig.init=commturk_sig, iter=commturk_numIter, DR.est="High")




##########################################################################################################
# UNCERTAINTY ANALYSIS CODE
##########################################################################################################

iter <- commturk_numIter

FoodNet.cases <- 7600  # per year
share.food <-	0.66 #foodborne fraction (else is waterborne)
share.foreign <- 0.11 # foreign travel associated illnesses 
FoodNet.coverage <- 0.15 # FoodNet sites comprise 15% of U.S. population
UnderDx.mult <-	rgamma(iter,32.83,1/0.74)  # 24.3 is avg number of true cases for each reported case (gamma(32.83 ,0.74))
Tot.salm.yr	<- FoodNet.cases*share.food*(1-share.foreign) * UnderDx.mult/FoodNet.coverage

turk.attrib <-	rpert(iter,0.01,0.059,0.108)  #0.058 share of all illnesses attributed to turkey consumption 

comm.ill <- Tot.salm.yr*turk.attrib*0.42
round(mean(comm.ill),-3)
round(quantile(comm.ill,c(0.025,0.975)),-3)

# The parameters of Pert distributions for the uncertain effectiveness of
# selected concentration thresholds.  The modes are the perc.red outputs from the baseline 
# model simulation.  The upper bounds are the perc.red outputs from the model approximation described
# above.  The lower bounds are the perc.red outputs from the model for the sensitivity analysis scenario
# where log.atten.mu <- 2.

turk.perc.red <- comm_turk_fps$perc.red[which(comm_turk_fps$conc.thresh %in% c(1/30,1,10,100))]

turk.lo <- final_prod_std(conc.thresh=c(1/30,1,10,100),p.c1=commturk_pc1, mu.init=commturk_mu, sig.init=commturk_sig, iter=commturk_numIter, atten.mu.X = 2)
turk.perc.red.lo <- turk.lo$perc.red

turk.perc.red.hi <- turk.effect$effect.init[which(turk.effect$conc.thresh %in% c(1/30,1,10,100))]

pr <- rbind(conc.thresh=c(1/30,1,10,100),turk.perc.red.lo,turk.perc.red,turk.perc.red.hi)
pr

tmp = apply(pr[-1,], 2, function(x) rpert(commturk_numIter, x[1], x[2], x[3]))*comm.ill

# apply(tmp, 2, function(x) round(quantile(x,c(0.025,0.975)),-3))

output <- rbind(mean(comm.ill)*pr[3,],
                apply(tmp, 2, function(x) quantile(x,c(0.025,0.975))))
output




########################################################################################################
# "ILLUSTRATIVE DOSE" CALCULATIONS
########################################################################################################

# assume a given initial conc and determine doses for comminuted turkey 

mu.init <- commturk_mu
sig.init <- commturk_sig

# attenuation distribution 
log.atten.mu <- -5
log.atten.sig <- 1.91

# specify concentration thresholds of interest
mu.init.ex <- c(1/325,1/30,1,10,100)

# what is exp val among failing lots?
omega <- pnorm(log10(mu.init.ex),mu.init,sig.init)

ev.init <- exp(mu.init*log(10)+0.5*(log(10)*sig.init)^2)

ev.pass <- (ev.init*pnorm((log(mu.init.ex)-mu.init*log(10)-(sig.init*log(10))^2)/(sig.init*log(10)),0,1))/omega

ev.fail <- (ev.init-omega*ev.pass)/(1-omega)

#what is exp val of dose if propagate ev.fail through attenuation?
ev.dose.fail <- exp(log(ev.fail)+log.atten.mu*log(10)+0.5*(log.atten.sig*log(10))^2)

# integrate exp val of failing lots across DR
p.ill.dose.C1 <- rep(0,length(mu.init.ex))
p.ill.dose.C2 <- rep(0,length(mu.init.ex))
for (i in 1:length(mu.init.ex)) {
  p.ill.dose.C1[i] <- integrate(f,-Inf, Inf, mu=log10(ev.fail[i])+log.atten.mu, sigma=log.atten.sig, cluster=1, est="Mean")$value 
  p.ill.dose.C2[i] <- integrate(f,-Inf, Inf, mu=log10(ev.fail[i])+log.atten.mu, sigma=log.atten.sig, cluster=2, est="Mean")$value
}

cbind(mu.init.ex,ev.fail,ev.dose.fail,p.ill.dose.C1,p.ill.dose.C2,1-omega)



