################################################################################
# © 2022 EpiX Analytics LLC
# The code  below is provided by EpiX Analytics to FSIS under the Cooperative Agreement (FSIS-02152022). 
# EpiX Analytics retains its right, title and interest, including its intellectual property rights to this code.
# the code is intended to be used only for the purposes of FSIS' two risk assessments titled: 
#   "Quantitative Risk Assessment for Salmonella in Raw Chicken and Raw Chicken Products"
#   "Quantitative Risk Assessment for Salmonella in Raw Turkey and Raw Turkey Products"
# Any other uses are prohibited without explicit approval by EpiX Analytics. For any questions, please contact info@epixanalyics.com

# The code provides a fast implementation of the dose-response curves for Salmonella Serovars grouped by virulence 
# using polynomials. See EpiX Analytics report, Appendix A of FSIS’ risk assessment reports for more details.
################################################################################
#arguments
nCluster <- 2 #Number of clusters to be used to adjust DR curves. Currently: 2
#SET WORKING DIRECTORY (setwd) TO ACCESS POLYNOMIAL2.CSV FILE

################################################################################
# This function provides a fast approximation for the results of a beta-Poisson DR 
# fitted using the confluent hypergeometric function of the second kind.
# Given parameter uncertainty, the resulting function is NOT a beta-Poisson, thus requiring 
# this portable format to avoid repeating computationally intensive inference.
# Valid for dose from 10^-14 to 10^10 cfu

Poly <- as.matrix(read.csv(paste0("Polynomial",nCluster,".csv"))[,-c(1,2)])  #Imports Polynomial coefficients
#Drops first two columns which are labels
#Remainder are 9 poly terms and Confidence intervals, for C1, C2, ...

DRPoly <- function(dose) {
  # Main dose-response using polymomials
  # input: dose (mean of the expected Poisson)
  # Output: a data frame: C1 Mean, Low, High: mean prob of illness for Cluster 1
  #                       C2 Mean, Low, High: mean prob of illness for Cluster 2
  #                       ...
  dose[dose > 1E10] <- 1E10 
  ldose <- log(dose+1)
  ldose <- cbind(ldose, ldose^2, ldose^3,ldose^4,ldose^5,ldose^6,ldose^7,ldose^8,ldose^9)
  coef <- Poly 
  res <- ldose %*% coef # doses x matrix of 9 coefficients' means and Low/High, for above cluster list
  rownames(res) <- dose
  return(as.data.frame(res))
}


# Numerical integration
DRPolyForInteg <- function(dose, cluster,est=c("Mean","Low","High")){
  Res <- DRPoly(dose) 
  return(as.vector(Res[[paste0("C",cluster,est)]]))
}

# The function to integrate -log10 normal mu, sigma, for cluster i
f <- function(x, mu, sigma, cluster, estimate) {
  dnorm(x, mean=mu, sd = sigma) * DRPolyForInteg(10^x, cluster, estimate)
}
