## Code for FSIS' 2024 Risk Assessments
## Code to analyze turkey carcass data for process control of indicator organisms

## The data necessary to implement this model has establishment identifying volume information and is therefore not provided.


#######################################
##### SET WORKING DIRECTORY       #####
#######################################

# Notes on files/etc

# Use 'setwd' to identify working directory where all files are saved
# e.g., setwd('Documents/FSIS_2024_Sal_Risk_Assessment_Model_Code/Turkey')


#######################################
##### LOAD LIBRARIES              #####
#######################################


library(dplyr) 
library(tidyr)
library(ggplot2)
library(rcartocolor)  ## using for color palettes

#######################################
##### Begin                       #####
#######################################


db_est=function(s,n,w) {
  ###############################################
  #  returns the prevalence estimate, variance, 
  #  coef. variation and confidence intervals for
  #  the estimators derived under the design-
  #  based inferenctial paradigm
  ###############################################
  
  p.estab=s/n
  p.hat=sum(w*p.estab)
  v.estab=p.estab*(1-p.estab)/(n-1) 
  v.hat=sum(w*w*v.estab)
  alpha.hat=( p.hat*(1-p.hat)/v.hat-1 )*p.hat
  beta.hat=( p.hat*(1-p.hat)/v.hat-1 )*(1-p.hat)
  dbeta
  
  return(cbind(p.hat=p.hat, v.hat=v.hat, cv.p.hat=sqrt(v.hat)/p.hat,lo.hat=qbeta(0.025,alpha.hat, beta.hat), up.hat=qbeta(0.975,alpha.hat, beta.hat)))
  
}

#dat = read.csv() ##Read in data if available. 

############################################################################################

num.estab = nrow(dat)

## indicating pass/fail for current performance stds on turkey carcasses
pass.prev = dat$pass.ps

steps=30

alf=0.5 #alpha is fraction of establishment expected to become passing if compliance is optional 

param.fail = param.pass = prev.alpha= array(0, dim=c(steps,5,3))

apc.cut.off = rep(0,steps)
apc.lod.cut.off = rep(0,steps)
eb.lod.cut.off = rep(0,steps)

omega=num.pass=Se=Sp=both.pass=matrix(0,nrow=steps,ncol=3)

n=dat$num.sam
n=ifelse(dat$neg.pc+dat$pos.pc==1,1.5,dat$neg.pc+dat$pos.pc) #add 1/2 for estab with 1 sample to do
p=dat$pos.pc/n
s=dat$pos.pc
w=dat$wt
print(db_est(dat$pos.pc,n,w))
pop.params=db_est(s,n,w)

for (i in 1:steps) {
  
  apc.cut.off[i]=0.0+0.1*i   ## apc log reduction metric 
  apc.lod.cut.off[i]=-0.05+0.05*i   ## apc below LOD metric 
  eb.lod.cut.off[i]=-0.05+0.05*i   ## eb below LOD metric 
  
  ## which estabs pass cutoff metrics; mark T/F
  passing.apc=subset(dat, ifelse(dat$dif.cen.apc.mean>=apc.cut.off[i],T,F)) 
  passing.apc.lod=subset(dat, ifelse(dat$frac.cen.apc.pc>=apc.lod.cut.off[i],T,F))
  passing.eb.lod=subset(dat, ifelse(dat$frac.cen.eb.pc>=eb.lod.cut.off[i],T,F))
  
  ## sensitivity & specificity calculations
  Se[i,1]=sum(ifelse(dat$dif.cen.apc.mean>=apc.cut.off[i],1,0)*dat$pass.ps)/sum(pass.prev)  
  Sp[i,1]=sum(ifelse(dat$dif.cen.apc.mean<apc.cut.off[i],1,0)*(1-dat$pass.ps))/sum(1-pass.prev)  
  
  Se[i,2]=sum(ifelse(dat$frac.cen.apc.pc>=apc.lod.cut.off[i],1,0)*dat$pass.ps)/sum(pass.prev)  
  Sp[i,2]=sum(ifelse(dat$frac.cen.apc.pc<apc.lod.cut.off[i],1,0)*(1-dat$pass.ps))/sum(1-pass.prev)  
  
  Se[i,3]=sum(ifelse(dat$frac.cen.eb.pc>=eb.lod.cut.off[i],1,0)*dat$pass.ps)/sum(pass.prev)  
  Sp[i,3]=sum(ifelse(dat$frac.cen.eb.pc<eb.lod.cut.off[i],1,0)*(1-dat$pass.ps))/sum(1-pass.prev)
  
  ## total passing
  num.pass[i,]=c(length(passing.apc$pos.pc), length(passing.apc.lod$pos.pc), length(passing.eb.lod$pos.pc))
  
  ## which FAIL cutoff metrics; mark T/F
  failing.apc=subset(dat, ifelse(dat$dif.cen.apc.mean>apc.cut.off[i],F,T)) 
  failing.apc.lod=subset(dat, ifelse(dat$frac.cen.apc.pc>apc.lod.cut.off[i],F,T))
  failing.eb.lod=subset(dat, ifelse(dat$frac.cen.eb.pc>eb.lod.cut.off[i],F,T))
  
  ## proportion of production volume that passes
  omega[i,]=c(sum(passing.apc$w)/sum(dat$w),
              sum(passing.apc.lod$w)/sum(dat$w),
              sum(passing.eb.lod$w)/sum(dat$w))
  
  n=ifelse(dat$neg.pc+dat$pos.pc==1,1.5,dat$neg.pc+dat$pos.pc) #add 1/2 for estab with 1 sample to do
  
  s=dat$pos.pc  ## num positive samples
  
  w=dat$wt
  
  ### design based model estimates
  param.pass[i,,1]=db_est(passing.apc$pos.pc,
                          ifelse(passing.apc$num.sam==1,1.5,passing.apc$num.sam), 
                          passing.apc$w/sum(passing.apc$w))
  param.fail[i,,1]=db_est(failing.apc$pos.pc,
                          ifelse(failing.apc$num.sam==1,1.5,failing.apc$num.sam), 
                          failing.apc$w/sum(failing.apc$w))

  param.pass[i,,2]=db_est(passing.apc.lod$pos.pc,
                          ifelse(passing.apc.lod$num.sam==1,1.5,passing.apc.lod$num.sam), 
                          passing.apc.lod$w/sum(passing.apc.lod$w))
  param.fail[i,,2]=db_est(failing.apc.lod$pos.pc,
                          ifelse(failing.apc.lod$num.sam==1,1.5,failing.apc.lod$num.sam), 
                          failing.apc.lod$w/sum(failing.apc.lod$w))
  
  param.pass[i,,3]=db_est(passing.eb.lod$pos.pc,
                          ifelse(passing.eb.lod$num.sam==1,1.5,passing.eb.lod$num.sam), 
                          passing.eb.lod$w/sum(passing.eb.lod$w))
  param.fail[i,,3]=db_est(failing.eb.lod$pos.pc,
                          ifelse(failing.eb.lod$num.sam==1,1.5,failing.eb.lod$num.sam), 
                          failing.eb.lod$w/sum(failing.eb.lod$w))
  
  ### alpha = 50% compliance model approach
  prev.alpha[i,,1]=(omega[i,1]+alf-alf*omega[i,1])*param.pass[i,,1] + (1-omega[i,1])*(1-alf)*param.fail[i,,1]
  prev.alpha[i,,2]=(omega[i,2]+alf-alf*omega[i,2])*param.pass[i,,2] + (1-omega[i,2])*(1-alf)*param.fail[i,,2]
  prev.alpha[i,,3]=(omega[i,3]+alf-alf*omega[i,3])*param.pass[i,,3] + (1-omega[i,3])*(1-alf)*param.fail[i,,3]
  
  #Se and Sp
  both.pass[i,1]=sum(ifelse(dat$dif.cen.apc.mean>apc.cut.off[i],1,0)*dat$pass.ps)
  both.pass[i,2]=sum(ifelse(dat$frac.cen.apc.pc>apc.lod.cut.off[i],1,0)*dat$pass.ps)
  both.pass[i,3]=sum(ifelse(dat$frac.cen.eb.pc>eb.lod.cut.off[i],1,0)*dat$pass.ps)
  
}   


#### AC reduction
data.frame(thresh=apc.cut.off,
                pass=param.pass[,1,1],
                fail=param.fail[,1,1],
                alpha=prev.alpha[,1,1]) %>%
  pivot_longer(cols=2:4,names_to="Group",values_to="Prop") %>%
  ggplot(aes(x=thresh,y=Prop,col=Group))+
    geom_line()+geom_point(size=2)+
    geom_hline(yintercept = pop.params[1])+
    geom_hline(yintercept = pop.params[1]*0.75,linetype="dashed")+
    geom_vline(xintercept=1,col="orange")+
    geom_vline(xintercept=2.3,col="darkgreen")+
    labs(x="Minimum AC log reduction",y="Proportion")+
    scale_color_carto_d(palette="Safe")+
    theme_bw()

data.frame(thresh=apc.cut.off,volume=omega[,1],establishments=num.pass[,1]/num.estab) %>%
  pivot_longer(cols=2:3,names_to="Group",values_to="Prop") %>%
  ggplot(aes(thresh,Prop,col=factor(Group)))+geom_line()+geom_point()+
    geom_vline(xintercept=1,col="orange")+
    geom_vline(xintercept=2.3,col="darkgreen")+
    labs(x="Minimum AC log reduction",y="Proportion passing",col=NULL)+
    scale_color_carto_d(palette="Safe")+
    theme_bw()

data.frame(thresh=apc.cut.off,sensitivity=Se[,1],specificity=Sp[,1]) %>% 
  pivot_longer(cols=2:3,names_to="grp",values_to="y") %>%
  ggplot(aes(x=thresh,y=y,col=factor(grp)))+geom_line()+geom_point()+
    geom_vline(xintercept=1,col="orange")+
    geom_vline(xintercept=2.3,col="darkgreen")+
    labs(x="Minimum AC log reduction",y="Performance",col=NULL)+
    theme_bw()


#### AC elimination

data.frame(thresh=apc.lod.cut.off,
           pass=param.pass[,1,2],
           fail=param.fail[,1,2],
           alpha=prev.alpha[,1,2]) %>%
  pivot_longer(cols=2:4,names_to="Group",values_to="Prop") %>%
  ggplot(aes(x=thresh,y=Prop,col=Group))+
  geom_line()+geom_point(size=2)+xlim(c(0,1))+
  geom_hline(yintercept = pop.params[1])+
  geom_hline(yintercept = pop.params[1]*0.75,linetype="dashed")+
  geom_vline(xintercept=0.2,col="orange")+
  geom_vline(xintercept=0.3,col="darkgreen")+
  labs(x="Proportion of no AC detections",y="Proportion")+
  scale_color_carto_d(palette="Safe")+
  theme_bw()

data.frame(thresh=apc.lod.cut.off,volume=omega[,2],establishments=num.pass[,2]/num.estab) %>%
  pivot_longer(cols=2:3,names_to="Group",values_to="Prop") %>%
  ggplot(aes(thresh,Prop,col=factor(Group)))+geom_line()+geom_point()+xlim(c(0,1))+
  geom_vline(xintercept=0.2,col="orange")+
  geom_vline(xintercept=0.3,col="darkgreen")+
  labs(x="Proportion of no AC detections",y="Proportion passing",col=NULL)+
  scale_color_carto_d(palette="Safe")+
  theme_bw()

data.frame(thresh=apc.lod.cut.off,sensitivity=Se[,2],specificity=Sp[,2]) %>% 
  pivot_longer(cols=2:3,names_to="grp",values_to="y") %>%
  ggplot(aes(x=thresh,y=y,col=factor(grp)))+geom_line()+geom_point()+xlim(c(0,1))+
  geom_vline(xintercept=0.2,col="orange")+
  geom_vline(xintercept=0.3,col="darkgreen")+
  labs(x="Proportion of no AC detections",y="Performance",col=NULL)+
  theme_bw()

#### EB elimination

data.frame(thresh=eb.lod.cut.off,
                pass=param.pass[,1,2],
                fail=param.fail[,1,2],
                alpha=prev.alpha[,1,2]) %>%
  pivot_longer(cols=2:4,names_to="Group",values_to="Prop") %>%
  ggplot(aes(x=thresh,y=Prop,col=Group))+
    geom_line()+geom_point(size=2)+xlim(c(0,1))+
    geom_hline(yintercept = pop.params[1])+
    geom_hline(yintercept = pop.params[1]*0.75,linetype="dashed")+
    geom_vline(xintercept=0.45,col="orange")+
    geom_vline(xintercept=0.8,col="darkgreen")+
    labs(x="Proportion of no EB detections",y="Proportion")+
    scale_color_carto_d(palette="Safe")+
    theme_bw()

data.frame(thresh=eb.lod.cut.off,volume=omega[,2],establishments=num.pass[,2]/num.estab) %>%
  pivot_longer(cols=2:3,names_to="Group",values_to="Prop") %>%
  ggplot(aes(thresh,Prop,col=factor(Group)))+geom_line()+geom_point()+xlim(c(0,1))+
    geom_vline(xintercept=0.45,col="orange")+
    geom_vline(xintercept=0.8,col="darkgreen")+
    labs(x="Proportion of no EB detections",y="Proportion passing",col=NULL)+
    scale_color_carto_d(palette="Safe")+
    theme_bw()

data.frame(thresh=eb.lod.cut.off,sensitivity=Se[,2],specificity=Sp[,2]) %>% 
  pivot_longer(cols=2:3,names_to="grp",values_to="y") %>%
  ggplot(aes(x=thresh,y=y,col=factor(grp)))+geom_line()+geom_point()+xlim(c(0,1))+
    geom_vline(xintercept=0.45,col="orange")+
    geom_vline(xintercept=0.8,col="darkgreen")+
    labs(x="Proportion of no EB detections",y="Performance",col=NULL)+
    theme_bw()
